# sequana_coverage

**DOI:** [10.5281/zenodo.13946413](https://doi.org/10.5281/zenodo.13946413)

## Available Versions
- **Version 0.18.0**
  - [Download](https://zenodo.org/record/13946414/files/sequana_coverage_0.18.0.img)
  - **MD5:** `a94b2f309fdc5f49bfc4ea46f56bae71`
  - **DOI:** [10.5281/zenodo.13946414](https://doi.org/10.5281/zenodo.13946414)
  - **Size:** 752.22 MB
  - **Binaries:** 0 available

## Binaries (1 total)

```sequana_coverage```
